"use strict";
var _routeKind = require("../../route-kind");
var _devAppRouteRouteMatcherProvider = require("./dev-app-route-route-matcher-provider");
describe("DevAppRouteRouteMatcher", ()=>{
    const dir = "<root>";
    const extensions = [
        "ts",
        "tsx",
        "js",
        "jsx"
    ];
    it("returns no routes with an empty filesystem", async ()=>{
        const reader = {
            read: jest.fn(()=>[])
        };
        const matcher = new _devAppRouteRouteMatcherProvider.DevAppRouteRouteMatcherProvider(dir, extensions, reader);
        const matchers = await matcher.matchers();
        expect(matchers).toHaveLength(0);
        expect(reader.read).toBeCalledWith(dir);
    });
    describe("filename matching", ()=>{
        it.each([
            {
                files: [
                    `${dir}/some/other/route.ts`
                ],
                route: {
                    kind: _routeKind.RouteKind.APP_ROUTE,
                    pathname: "/some/other",
                    filename: `${dir}/some/other/route.ts`,
                    page: "/some/other/route",
                    bundlePath: "app/some/other/route"
                }
            },
            {
                files: [
                    `${dir}/route.ts`
                ],
                route: {
                    kind: _routeKind.RouteKind.APP_ROUTE,
                    pathname: "/",
                    filename: `${dir}/route.ts`,
                    page: "/route",
                    bundlePath: "app/route"
                }
            }, 
        ])("matches the '$route.page' route specified with the provided files", async ({ files , route  })=>{
            const reader = {
                read: jest.fn(()=>[
                        ...extensions.map((ext)=>`${dir}/some/page.${ext}`),
                        ...extensions.map((ext)=>`${dir}/api/other.${ext}`),
                        ...files, 
                    ])
            };
            const matcher = new _devAppRouteRouteMatcherProvider.DevAppRouteRouteMatcherProvider(dir, extensions, reader);
            const matchers = await matcher.matchers();
            expect(matchers).toHaveLength(1);
            expect(reader.read).toBeCalledWith(dir);
            expect(matchers[0].definition).toEqual(route);
        });
    });
});

//# sourceMappingURL=dev-app-route-route-matcher-provider.test.js.map