"use strict";
var _routeKind = require("../../route-kind");
var _devPagesRouteMatcherProvider = require("./dev-pages-route-matcher-provider");
describe("DevPagesRouteMatcherProvider", ()=>{
    const dir = "<root>";
    const extensions = [
        "ts",
        "tsx",
        "js",
        "jsx"
    ];
    it("returns no routes with an empty filesystem", async ()=>{
        const reader = {
            read: jest.fn(()=>[])
        };
        const matcher = new _devPagesRouteMatcherProvider.DevPagesRouteMatcherProvider(dir, extensions, reader);
        const matchers = await matcher.matchers();
        expect(matchers).toHaveLength(0);
        expect(reader.read).toBeCalledWith(dir);
    });
    describe("filename matching", ()=>{
        it.each([
            {
                files: [
                    `${dir}/index.ts`
                ],
                route: {
                    kind: _routeKind.RouteKind.PAGES,
                    pathname: "/",
                    filename: `${dir}/index.ts`,
                    page: "/",
                    bundlePath: "pages/index"
                }
            },
            {
                files: [
                    `${dir}/some/api/route.ts`
                ],
                route: {
                    kind: _routeKind.RouteKind.PAGES,
                    pathname: "/some/api/route",
                    filename: `${dir}/some/api/route.ts`,
                    page: "/some/api/route",
                    bundlePath: "pages/some/api/route"
                }
            },
            {
                files: [
                    `${dir}/some/other/route/index.ts`
                ],
                route: {
                    kind: _routeKind.RouteKind.PAGES,
                    pathname: "/some/other/route",
                    filename: `${dir}/some/other/route/index.ts`,
                    page: "/some/other/route",
                    bundlePath: "pages/some/other/route"
                }
            },
            {
                files: [
                    `${dir}/some/other/route/index/route.ts`
                ],
                route: {
                    kind: _routeKind.RouteKind.PAGES,
                    pathname: "/some/other/route/index/route",
                    filename: `${dir}/some/other/route/index/route.ts`,
                    page: "/some/other/route/index/route",
                    bundlePath: "pages/some/other/route/index/route"
                }
            }, 
        ])("matches the '$route.page' route specified with the provided files", async ({ files , route  })=>{
            const reader = {
                read: jest.fn(()=>[
                        ...extensions.map((ext)=>`${dir}/api/other/page.${ext}`),
                        ...files, 
                    ])
            };
            const matcher = new _devPagesRouteMatcherProvider.DevPagesRouteMatcherProvider(dir, extensions, reader);
            const matchers = await matcher.matchers();
            expect(matchers).toHaveLength(1);
            expect(reader.read).toBeCalledWith(dir);
            expect(matchers[0].definition).toEqual(route);
        });
    });
});

//# sourceMappingURL=dev-pages-route-matcher-provider.test.js.map