"use strict";
var _constants = require("../../../shared/lib/constants");
var _routeKind = require("../route-kind");
var _pagesApiRouteMatcherProvider = require("./pages-api-route-matcher-provider");
describe("PagesAPIRouteMatcherProvider", ()=>{
    it("returns no routes with an empty manifest", async ()=>{
        const loader = {
            load: jest.fn(()=>({}))
        };
        const provider = new _pagesApiRouteMatcherProvider.PagesAPIRouteMatcherProvider("<root>", loader);
        expect(await provider.matchers()).toEqual([]);
        expect(loader.load).toBeCalledWith(_constants.PAGES_MANIFEST);
    });
    describe("manifest matching", ()=>{
        it.each([
            {
                manifest: {
                    "/api/users/[id]": "pages/api/users/[id].js"
                },
                route: {
                    kind: _routeKind.RouteKind.PAGES_API,
                    pathname: "/api/users/[id]",
                    filename: `<root>/${_constants.SERVER_DIRECTORY}/pages/api/users/[id].js`,
                    page: "/api/users/[id]",
                    bundlePath: "pages/api/users/[id]"
                }
            },
            {
                manifest: {
                    "/api/users": "pages/api/users.js"
                },
                route: {
                    kind: _routeKind.RouteKind.PAGES_API,
                    pathname: "/api/users",
                    filename: `<root>/${_constants.SERVER_DIRECTORY}/pages/api/users.js`,
                    page: "/api/users",
                    bundlePath: "pages/api/users"
                }
            },
            {
                manifest: {
                    "/api": "pages/api.js"
                },
                route: {
                    kind: _routeKind.RouteKind.PAGES_API,
                    pathname: "/api",
                    filename: `<root>/${_constants.SERVER_DIRECTORY}/pages/api.js`,
                    page: "/api",
                    bundlePath: "pages/api"
                }
            }, 
        ])("returns the correct routes for $route.pathname", async ({ manifest , route  })=>{
            const loader = {
                load: jest.fn(()=>({
                        "/users/[id]": "pages/users/[id].js",
                        "/users": "pages/users.js",
                        ...manifest
                    }))
            };
            const provider = new _pagesApiRouteMatcherProvider.PagesAPIRouteMatcherProvider("<root>", loader);
            const matchers = await provider.matchers();
            expect(loader.load).toBeCalledWith(_constants.PAGES_MANIFEST);
            expect(matchers).toHaveLength(1);
            expect(matchers[0].definition).toEqual(route);
        });
    });
});

//# sourceMappingURL=pages-api-route-matcher-provider.test.js.map